#!/usr/bin/env python

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Program: Computer Info
# Written by Antti Luukkonen <antti.luukkonen@helsinki.fi>
# 4.5.2015

import gtk
import subprocess
import os

VERSION = '0.3'

class InfoWin:

    def __init__(self):

        # Computer Name
        self.name = subprocess.check_output("hostname", shell=True).strip()
        self.hname = "Computer name: "

        # Username
        self.user = subprocess.check_output("whoami", shell=True).strip()
        self.huser = "Username: "

        # CPU
        self.cpu = subprocess.check_output("grep 'model name' /proc/cpuinfo | cut -f 2 | cut -c 3- | tail -1", shell=True).strip()
        self.hcpu = "CPU: "

        # Memory
        self.mem = subprocess.check_output("free -m | awk 'FNR == 2 {print $2}'", shell=True).strip()
        self.hmem = "RAM (MB): "

        # IP Address
        if len(subprocess.check_output("hostname -I", shell=True)) > 17:
            self.ips = subprocess.check_output("hostname -I", shell=True).split()
            self.ip = self.ips[0] + "\t" + self.ips[1]
        else:
            self.ip = subprocess.check_output("hostname -I", shell=True).strip()
        self.hip = "IP address: "

        # FQDN
        self.fqdn = subprocess.check_output("hostname --fqdn", shell=True).strip()
        self.hfqdn = "DNS address: "

        # MAC Address
        self.mac = subprocess.check_output("cat /sys/class/net/*/address | awk 'FNR == 1 {print}' | sed 's/://g'", shell=True).upper().strip()
        self.hmac = "MAC address: "

        # OS Version
        self.osv = subprocess.check_output("lsb_release -d | cut -f 2", shell=True).strip()
        self.hosv = "Operating system: "

        # Last Updated
        self.lupdate = subprocess.check_output("tail -1 /var/log/dpkg.log | awk '{print $1, $2}'", shell=True).strip()
        self.hlupdate = "Last updated: "

        # Local Drives
        self.ldrives = subprocess.check_output("df -h / /home", shell=True).strip()
        self.hldrives = "Local drives: "

        # Network Drives
        if subprocess.check_output("quota -s", shell=True):
            self.netdrives = subprocess.check_output("quota -s | awk 'FNR == 4 {print $1}'", shell=True).strip()
        else:
            self.netdrives = "Info not available" # tahan subprocess mika palauttaa z-aseman statsit
        self.hnetdrives = "Network drive (used): "
        
        # Create a new window
        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.window.set_title("Computer Info")
        
        # Close the window
        self.window.connect("destroy", lambda w: gtk.main_quit())

        # Size of the window
        self.window.set_size_request(600, 360)
        self.window.set_position(gtk.WIN_POS_CENTER)

        self.vbox = gtk.VBox(False, 0)
        self.window.add(self.vbox)
        self.window.set_border_width(10)

        # Create a table for the labels
        table = gtk.Table(10, 2, True)

        # Attach labels to the table
        table.attach(self.create_label(self.hname), 0, 1, 0, 1, ypadding=5)
        table.attach(self.create_label(self.name), 1, 2, 0, 1, ypadding=5)
        table.attach(self.create_label(self.hcpu), 0, 1, 1, 2, ypadding=5)
        table.attach(self.create_label(self.cpu), 1, 2, 1, 2, ypadding=5)
        table.attach(self.create_label(self.hmem), 0, 1, 2, 3, ypadding=5)
        table.attach(self.create_label(self.mem), 1, 2, 2, 3, ypadding=5)
        table.attach(self.create_label(self.hosv), 0, 1, 3, 4, ypadding=5)
        table.attach(self.create_label(self.osv), 1, 2, 3, 4, ypadding=5)
        table.attach(self.create_label(self.hlupdate), 0, 1, 4, 5, ypadding=5)
        table.attach(self.create_label(self.lupdate), 1, 2, 4, 5, ypadding=5)
        table.attach(self.create_label(self.hfqdn), 0, 1, 5, 6, ypadding=5)
        table.attach(self.create_label(self.fqdn), 1, 2, 5, 6, ypadding=5)
        table.attach(self.create_label(self.hip), 0, 1, 6, 7, ypadding=5)
        table.attach(self.create_label(self.ip), 1, 2, 6, 7, ypadding=5)
        table.attach(self.create_label(self.hmac), 0, 1, 7, 8, ypadding=5)
        table.attach(self.create_label(self.mac), 1, 2, 7, 8, ypadding=5)
        table.attach(self.create_label(self.hldrives), 0, 1, 8, 9, ypadding=5)
        table.attach(self.create_label(self.ldrives), 1, 2, 8, 10, ypadding=5)
        table.attach(self.create_label(self.hnetdrives), 0, 1, 10, 11, ypadding=5)
        table.attach(self.create_label(self.netdrives), 1, 2, 10, 11, ypadding=5)

        table.set_homogeneous(False)

        # Show the table
        self.vbox.pack_start(table, True, True, 0)

        # Clipboard
        self.clipboard = gtk.clipboard_get(gtk.gdk.SELECTION_CLIPBOARD)

        # Copy button
        self.button = gtk.Button("Copy the info to clipboard")
        self.button.connect("clicked", self.set_clipboard)
        self.button_fixed = gtk.Fixed()
        self.button_fixed.put(self.button, 200, 10)
        self.vbox.add(self.button_fixed)
        self.button_fixed.show()

        # Shows the window
        self.window.show_all()

    def create_label(self, content1):

        label = gtk.Label(content1)
        label.set_alignment(0, 0.5)
        return label

    def set_clipboard(self, widget):
        self.clipboard.set_text(self.hname + self.name + "\n" + self.hcpu + self.cpu + "\n" + self.hmem + self.mem + "\n" + self.hosv + self.osv + "\n" + self.hlupdate + self.lupdate + "\n" + self.hfqdn + self.fqdn + "\n" + self.hip + self.ip + "\n" + self.hmac + self.mac + "\n" + self.hldrives + "\n" + self.ldrives + "\n" + self.hnetdrives + self.netdrives)
        self.clipboard.store()
        return
    
def main():
    gtk.main()
    return 0

if __name__ == "__main__":
    InfoWin()
    main()

